@@ -1,14 +1,14 @@
 /*
-**  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: stats.c,v 1.10 2007/06/27 19:49:23 msk Exp $
+**  $Id: stats.c,v 1.12 2008/02/17 22:39:50 msk Exp $
 */
 
 #ifdef _FFR_STATS
 
 #ifndef lint
-static char stats_c_id[] = "@(#)$Id: stats.c,v 1.10 2007/06/27 19:49:23 msk Exp $";
+static char stats_c_id[] = "@(#)$Id: stats.c,v 1.12 2008/02/17 22:39:50 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -22,8 +22,6 @@ static char stats_c_id[] = "@(#)$Id: stats.c,v 1.10 2007/06/27 19:49:23 msk Exp
 #include <assert.h>
 #include <syslog.h>
 
-/* libdb includes */
-#include <db.h>
 
 /* libsm includes */
 #include <sm/gen.h>
@@ -36,20 +34,7 @@ static char stats_c_id[] = "@(#)$Id: stats.c,v 1.10 2007/06/27 19:49:23 msk Exp
 /* dkim-filter includes */
 #include "stats.h"
 #include "dkim-filter.h"
-
-/* definitions */
-#ifndef DB_NOTFOUND
-# define DB_NOTFOUND	1
-#endif /* ! DB_NOTFOUND */
-#define	DB_MODE		(S_IRUSR|S_IWUSR)
-
-#ifndef DB_VERSION_MAJOR
-# define DB_VERSION_MAJOR	1
-#endif /* ! DB_VERSION_MAJOR */
-
-#define	DB_VERSION_CHECK(x,y,z)	((DB_VERSION_MAJOR == (x) && \
-				  DB_VERSION_MINOR >= (y)) || \
-				 DB_VERSION_MAJOR > (x))
+#include "dkim-db.h"
 
 /* globals */
 static pthread_mutex_t stats_lock;
@@ -106,26 +91,7 @@ dkimf_stats_record(const char *path, const char *sigdomain,
 	pthread_mutex_lock(&stats_lock);
 
 	/* open the DB */
-#if DB_VERSION_CHECK(3,0,0)
-	status = db_create(&db, NULL, 0);
-	if (status == 0)
-	{
-# if DB_VERSION_CHECK(4,0,0)
-		status = db->open(db, NULL, path, NULL, DB_HASH,
-		                  (DB_CREATE|DB_THREAD), DB_MODE);
-# else /* DB_VERSION_CHECK(4,0,0) */
-		status = db->open(db, path, NULL, DB_HASH,
-		                  (DB_CREATE|DB_THREAD), DB_MODE);
-# endif /* DB_VERSION_CHECK(4,0,0) */
-	}
-#elif DB_VERSION_CHECK(2,0,0)
-	status = db_open(path, DB_HASH, (DB_CREATE|DB_THREAD), DB_MODE,
-	                 NULL, NULL, &db);
-#else /* DB_VERSION_CHECK(2,0,0) */
-	db = dbopen(path, (O_CREAT|O_RDWR), DB_MODE, DB_HASH, NULL);
-	if (db == NULL)
-		status = errno;
-#endif /* DB_VERSION_CHECK */
+	status = dkimf_db_open_rw(&db, path);
 
 	if (status != 0)
 	{
@@ -133,11 +99,7 @@ dkimf_stats_record(const char *path, const char *sigdomain,
 		{
 			char *err;
 
-#if DB_VERSION_CHECK(3,0,0)
-			err = db_strerror(status);
-#else /* DB_VERSION_CHECK(3,0,0) */
-			err = strerror(errno);
-#endif /* DB_VERSION_CHECK(3,0,0) */
+			err = DB_STRERROR(status);
 			syslog(LOG_ERR, "%s: db->open(): %s", path, err);
 		}
 
@@ -183,19 +145,11 @@ dkimf_stats_record(const char *path, const char *sigdomain,
 		{
 			char *err;
 
-#if DB_VERSION_CHECK(3,0,0)
-			err = db_strerror(status);
-#else /* DB_VERSION_CHECK(3,0,0) */
-			err = strerror(errno);
-#endif /* DB_VERSION_CHECK(3,0,0) */
+			err = DB_STRERROR(status);
 			syslog(LOG_ERR, "%s: db->get(): %s", path, err);
 		}
 
-#if DB_VERSION_CHECK(2,0,0)
-		(void) db->close(db, 0);
-#else /* DB_VERSION_CHECK(2,0,0) */
-		(void) db->close(db);
-#endif /* DB_VERSION_CHECK(2,0,0) */
+		DKIMF_DBCLOSE(db);
 
 		pthread_mutex_unlock(&stats_lock);
 
@@ -242,20 +196,12 @@ dkimf_stats_record(const char *path, const char *sigdomain,
 	{
 		char *err;
 
-#if DB_VERSION_CHECK(3,0,0)
-		err = db_strerror(status);
-#else /* DB_VERSION_CHECK(3,0,0) */
-		err = strerror(errno);
-#endif /* DB_VERSION_CHECK(3,0,0) */
+		err = DB_STRERROR(status);
 		syslog(LOG_ERR, "%s: db->put(): %s", path, err);
 	}
 
 	/* close the DB */
-#if DB_VERSION_CHECK(2,0,0)
-	(void) db->close(db, 0);
-#else /* DB_VERSION_CHECK(2,0,0) */
-	(void) db->close(db);
-#endif /* DB_VERSION_CHECK(2,0,0) */
+	DKIMF_DBCLOSE(db);
 
 	pthread_mutex_unlock(&stats_lock);
 }
