@@ -7,14 +7,14 @@
 #define _DKIM_POLICY_H_
 
 #ifndef lint
-static char dkim_policy_h_id[] = "@(#)$Id: dkim-policy.h,v 1.3 2007/06/28 18:23:40 msk Exp $";
+static char dkim_policy_h_id[] = "@(#)$Id: dkim-policy.h,v 1.4 2007/10/30 17:55:36 msk Exp $";
 #endif /* !lint */
 
 /* libdkim includes */
 #include "dkim.h"
 
 /* prototypes */
-extern int dkim_get_policy_dns __P((DKIM *, u_char *, u_char *,
+extern int dkim_get_policy_dns __P((DKIM *, u_char *, bool, u_char *,
                                     size_t, int *));
 extern int dkim_get_policy_file __P((DKIM *, u_char *, u_char *,
                                      size_t, int *));
